@@ -43,6 +43,8 @@ from . import shared
 
 _BASE_URL_ = 'https://query2.finance.yahoo.com'
 _SCRAPE_URL_ = 'https://finance.yahoo.com/quote'
+_ROOT_URL_ = 'https://finance.yahoo.com'
+
 
 class TickerBase():
     def __init__(self, ticker, session=None):
@@ -66,6 +68,8 @@ class TickerBase():
 
         self._calendar = None
         self._expirations = {}
+        self._earnings_dates = None
+        self._earnings_history = None
 
         self._earnings = {
             "yearly": utils.empty_df(),
@@ -144,20 +148,22 @@ class TickerBase():
         """
 
         if start or period is None or period.lower() == "max":
-            if start is None:
-                start = -631159200
-            elif isinstance(start, _datetime.datetime):
-                start = int(_time.mktime(start.timetuple()))
-            else:
-                start = int(_time.mktime(
-                    _time.strptime(str(start), '%Y-%m-%d')))
             if end is None:
                 end = int(_time.time())
             elif isinstance(end, _datetime.datetime):
                 end = int(_time.mktime(end.timetuple()))
             else:
-                end = int(_time.mktime(_time.strptime(str(end), '%Y-%m-%d')))
-
+                end = int(_time.mktime(_time.strptime(str(end), '%Y-%m-%d'))) 
+            if start is None:
+                if interval=="1m":
+                    start = end - 604800 # Subtract 7 days 
+                else:
+                    start = -631159200
+            elif isinstance(start, _datetime.datetime):
+                start = int(_time.mktime(start.timetuple()))
+            else:
+                start = int(_time.mktime(
+                    _time.strptime(str(start), '%Y-%m-%d')))
             params = {"period1": start, "period2": end}
         else:
             period = period.lower()
@@ -524,8 +530,10 @@ class TickerBase():
             shares = _pd.DataFrame(data['annualBasicAverageShares'])
             shares['Year'] = shares['asOfDate'].agg(lambda x: int(x[:4]))
             shares.set_index('Year', inplace=True)
-            shares.drop(columns=['dataId', 'asOfDate', 'periodType', 'currencyCode'], inplace=True)
-            shares.rename(columns={'reportedValue': "BasicShares"}, inplace=True)
+            shares.drop(columns=['dataId', 'asOfDate',
+                        'periodType', 'currencyCode'], inplace=True)
+            shares.rename(
+                columns={'reportedValue': "BasicShares"}, inplace=True)
             self._shares = shares
         except Exception:
             pass
@@ -549,22 +557,27 @@ class TickerBase():
                         if isinstance(colval, dict):
                             dict_cols.append(colname)
                             for k, v in colval.items():
-                                new_colname = colname + ' ' + utils.camel2title([k])[0]
+                                new_colname = colname + ' ' + \
+                                    utils.camel2title([k])[0]
                                 analysis.loc[idx, new_colname] = v
 
-                self._analysis = analysis[[c for c in analysis.columns if c not in dict_cols]]
+                self._analysis = analysis[[
+                    c for c in analysis.columns if c not in dict_cols]]
             except Exception:
                 pass
 
         # Complementary key-statistics (currently fetching the important trailingPegRatio which is the value shown in the website)
         res = {}
         try:
-            my_headers = {'user-agent': 'curl/7.55.1', 'accept': 'application/json', 'content-type': 'application/json', 'referer': 'https://finance.yahoo.com/', 'cache-control': 'no-cache', 'connection': 'close'}
+            my_headers = {'user-agent': 'curl/7.55.1', 'accept': 'application/json', 'content-type': 'application/json',
+                          'referer': 'https://finance.yahoo.com/', 'cache-control': 'no-cache', 'connection': 'close'}
             p = _re.compile(r'root\.App\.main = (.*);')
-            r = _requests.session().get('https://finance.yahoo.com/quote/{}/key-statistics?p={}'.format(self.ticker, self.ticker), headers=my_headers)
+            r = _requests.session().get('https://finance.yahoo.com/quote/{}/key-statistics?p={}'.format(self.ticker,
+                                                                                                        self.ticker), headers=my_headers)
             q_results = {}
             my_qs_keys = ['pegRatio']  # QuoteSummaryStore
-            my_ts_keys = ['trailingPegRatio']  # , 'quarterlyPegRatio']  # QuoteTimeSeriesStore
+            # , 'quarterlyPegRatio']  # QuoteTimeSeriesStore
+            my_ts_keys = ['trailingPegRatio']
 
             # Complementary key-statistics
             data = _json.loads(p.findall(r.text)[0])
@@ -578,7 +591,8 @@ class TickerBase():
                     zzz = key_stats['timeSeries'][i]
                     for j in range(len(zzz)):
                         if key_stats['timeSeries'][i][j]:
-                            res = {i: key_stats['timeSeries'][i][j]['reportedValue']['raw']}
+                            res = {i: key_stats['timeSeries']
+                                   [i][j]['reportedValue']['raw']}
                             q_results[self.ticker].append(res)
 
                 # print(res)
@@ -791,3 +805,121 @@ class TickerBase():
         # parse news
         self._news = data.get("news", [])
         return self._news
+
+    def get_earnings_dates(self, proxy=None):
+        if self._earnings_dates is not None:
+            return self._earnings_dates
+
+        # setup proxy in requests format
+        if proxy is not None:
+            if isinstance(proxy, dict) and "https" in proxy:
+                proxy = proxy["https"]
+            proxy = {"https": proxy}
+
+        page_size = 100  # YF caps at 100, don't go higher
+        page_offset = 0
+        dates = None
+        while True:
+            url = "{}/calendar/earnings?symbol={}&offset={}&size={}".format(
+                _ROOT_URL_, self.ticker, page_offset, page_size)
+
+            session = self.session or _requests
+            data = session.get(
+                url=url,
+                proxies=proxy,
+                headers=utils.user_agent_headers
+            ).text
+
+            if "Will be right back" in data:
+                raise RuntimeError("*** YAHOO! FINANCE IS CURRENTLY DOWN! ***\n"
+                                   "Our engineers are working quickly to resolve "
+                                   "the issue. Thank you for your patience.")
+
+            try:
+                data = _pd.read_html(data)[0]
+            except ValueError:
+                if page_offset == 0:
+                    # Should not fail on first page
+                    if "Showing Earnings for:" in data:
+                        # Actually YF was successful, problem is company doesn't have earnings history
+                        dates = utils.empty_earnings_dates_df()
+                break
+
+            if dates is None:
+                dates = data
+            else:
+                dates = _pd.concat([dates, data], axis=0)
+            page_offset += page_size
+
+        if dates is None:
+            raise Exception("No data found, symbol may be delisted")
+        dates = dates.reset_index(drop=True)
+
+        # Drop redundant columns
+        dates = dates.drop(["Symbol", "Company"], axis=1)
+
+        # Convert types
+        for cn in ["EPS Estimate", "Reported EPS", "Surprise(%)"]:
+            dates.loc[dates[cn] == '-', cn] = "NaN"
+            dates[cn] = dates[cn].astype(float)
+
+        # Convert % to range 0->1:
+        dates["Surprise(%)"] *= 0.01
+
+        # Parse earnings date string
+        cn = "Earnings Date"
+        # - remove AM/PM and timezone from date string
+        tzinfo = dates[cn].str.extract('([AP]M[a-zA-Z]*)$')
+        dates[cn] = dates[cn].replace(' [AP]M[a-zA-Z]*$', '', regex=True)
+        # - split AM/PM from timezone
+        tzinfo = tzinfo[0].str.extract('([AP]M)([a-zA-Z]*)', expand=True)
+        tzinfo.columns = ["AM/PM", "TZ"]
+        # - combine and parse
+        dates[cn] = dates[cn] + ' ' + tzinfo["AM/PM"]
+        dates[cn] = _pd.to_datetime(dates[cn], format="%b %d, %Y, %I %p")
+        # - instead of attempting decoding of ambiguous timezone abbreviation, just use 'info':
+        dates[cn] = dates[cn].dt.tz_localize(
+            tz=self.info["exchangeTimezoneName"])
+
+        dates = dates.set_index("Earnings Date")
+
+        self._earnings_dates = dates
+
+        return dates
+
+    def get_earnings_history(self, proxy=None):
+        if self._earnings_history:
+            return self._earnings_history
+
+        # setup proxy in requests format
+        if proxy is not None:
+            if isinstance(proxy, dict) and "https" in proxy:
+                proxy = proxy["https"]
+            proxy = {"https": proxy}
+
+        url = "{}/calendar/earnings?symbol={}".format(_ROOT_URL_, self.ticker)
+        session = self.session or _requests
+        data = session.get(
+            url=url,
+            proxies=proxy,
+            headers=utils.user_agent_headers
+        ).text
+
+        if "Will be right back" in data:
+            raise RuntimeError("*** YAHOO! FINANCE IS CURRENTLY DOWN! ***\n"
+                               "Our engineers are working quickly to resolve "
+                               "the issue. Thank you for your patience.")
+
+        try:
+            # read_html returns a list of pandas Dataframes of all the tables in `data`
+            data = _pd.read_html(data)[0]
+            data.replace("-", _np.nan, inplace=True)
+
+            data['EPS Estimate'] = _pd.to_numeric(data['EPS Estimate'])
+            data['Reported EPS'] = _pd.to_numeric(data['Reported EPS'])
+            self._earnings_history = data
+        # if no tables are found a ValueError is thrown
+        except ValueError:
+            print("Could not find data for {}.".format(self.ticker))
+            return
+        return data
